From cf4f96cef6d90838679858ea770bfb111b5fc77d Mon Sep 17 00:00:00 2001
From: Daniel <d.hornung@indiscale.com>
Date: Thu, 14 Nov 2024 13:27:05 +0100
Subject: [PATCH] WIP: More renaming CaosDB -> LinkAhead

---
 .docker/cert.sh                               |  2 +-
 .gitlab-ci.yml                                |  2 +-
 Makefile                                      |  2 +-
 RELEASE_GUIDELINES.md                         |  2 +-
 extra/emacs/snippets/yaml-mode/RecordType     |  2 +-
 integrationtests/clear_database.py            |  4 +-
 integrationtests/crawl.py                     |  4 +-
 integrationtests/create_analysis.py           |  4 +-
 integrationtests/example_hdf5cfood.py         |  4 +-
 integrationtests/insert_model.py              |  2 +-
 integrationtests/insert_some.py               |  2 +-
 integrationtests/test_assure_functions.py     |  4 +-
 .../test_base_table_exporter_integration.py   |  4 +-
 integrationtests/test_cache.py                |  4 +-
 .../test_crawl_with_datamodel_problems.py     |  4 +-
 integrationtests/test_crawler_basics.py       |  4 +-
 integrationtests/test_crawler_with_cfoods.py  |  6 +-
 integrationtests/test_data_model.py           |  2 +-
 integrationtests/test_datamodel_problems.py   |  6 +-
 integrationtests/test_im_und_export.py        |  4 +-
 .../test_json_schema_datamodel_parser.py      |  4 +-
 integrationtests/test_json_schema_exporter.py |  2 +-
 integrationtests/test_table.py                |  4 +-
 integrationtests/test_yaml_parser.py          |  4 +-
 integrationtests/update_analysis.py           |  4 +-
 manual_tests/test_labfolder_import.py         |  2 +-
 manual_tests/test_labfolder_retrieve.py       |  2 +-
 setup.py                                      |  2 +-
 src/caosadvancedtools/cache.py                |  4 +-
 src/caosadvancedtools/cfood.py                | 28 +++++-----
 src/caosadvancedtools/cfoods/__init__.py      |  2 +-
 src/caosadvancedtools/cfoods/h5.py            |  6 +-
 src/caosadvancedtools/collect_datamodel.py    |  6 +-
 .../converter/labfolder_api.py                |  4 +-
 .../converter/labfolder_export.py             |  4 +-
 src/caosadvancedtools/crawler.py              | 56 +++++++++----------
 src/caosadvancedtools/datainconsistency.py    |  2 +-
 src/caosadvancedtools/datamodel_problems.py   |  4 +-
 src/caosadvancedtools/example_cfood.py        |  4 +-
 src/caosadvancedtools/export_related.py       | 12 ++--
 src/caosadvancedtools/guard.py                |  4 +-
 src/caosadvancedtools/import_from_xml.py      |  6 +-
 src/caosadvancedtools/json_schema_exporter.py |  2 +-
 src/caosadvancedtools/loadFiles.py            |  4 +-
 src/caosadvancedtools/models/data_model.py    | 22 ++++----
 src/caosadvancedtools/models/parser.py        | 16 +++---
 src/caosadvancedtools/pandoc_header_tools.py  |  2 +-
 src/caosadvancedtools/read_md_header.py       |  4 +-
 .../scifolder/analysis_cfood.py               |  4 +-
 .../scifolder/experiment_cfood.py             |  2 +-
 .../scifolder/publication_cfood.py            |  2 +-
 .../scifolder/result_table_cfood.py           |  2 +-
 .../scifolder/simulation_cfood.py             |  2 +-
 .../scifolder/software_cfood.py               |  2 +-
 src/caosadvancedtools/scifolder/utils.py      |  2 +-
 src/caosadvancedtools/scifolder/withreadme.py |  2 +-
 .../serverside/examples/example_script.py     | 10 ++--
 .../serverside/generic_analysis.py            |  4 +-
 src/caosadvancedtools/serverside/helper.py    | 24 ++++----
 src/caosadvancedtools/structure_mapping.py    |  8 +--
 src/caosadvancedtools/table_converter.py      |  4 +-
 src/caosadvancedtools/table_export.py         |  8 +--
 src/caosadvancedtools/utils.py                |  6 +-
 src/doc/Makefile                              |  2 +-
 src/doc/crawler.rst                           |  2 +-
 unittests/create_filetree.py                  |  2 +-
 ...ignore-example => linkaheadignore-example} |  0
 unittests/test_base_table_exporter.py         |  4 +-
 unittests/test_cache.py                       |  4 +-
 unittests/test_caosdbignore.py                |  6 +-
 unittests/test_cfood.py                       |  4 +-
 unittests/test_crawler.py                     |  4 +-
 unittests/test_data_model.py                  |  2 +-
 unittests/test_generic_analysis.py            |  4 +-
 unittests/test_json_schema_exporter.py        |  2 +-
 unittests/test_json_schema_model_parser.py    |  6 +-
 unittests/test_read_md_header.py              |  4 +-
 unittests/test_result_table_cfood.py          |  4 +-
 unittests/test_sss_helper.py                  | 10 ++--
 unittests/test_structure_mapping.py           |  6 +-
 unittests/test_suppressKnown.py               |  2 +-
 unittests/test_table_converter.py             |  6 +-
 unittests/test_update_cache.py                |  4 +-
 unittests/test_utils.py                       | 10 ++--
 unittests/test_yaml_model_parser.py           |  2 +-
 85 files changed, 228 insertions(+), 228 deletions(-)
 rename unittests/{caosdbignore-example => linkaheadignore-example} (100%)

diff --git a/.docker/cert.sh b/.docker/cert.sh
index e22cfba2..c7253c77 100755
--- a/.docker/cert.sh
+++ b/.docker/cert.sh
@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Daniel Hornung, Göttingen
 #
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 65698d86..f9702235 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -1,5 +1,5 @@
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
diff --git a/Makefile b/Makefile
index 26f5c818..c53f7013 100644
--- a/Makefile
+++ b/Makefile
@@ -1,5 +1,5 @@
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/RELEASE_GUIDELINES.md b/RELEASE_GUIDELINES.md
index adeab4dd..11c84446 100644
--- a/RELEASE_GUIDELINES.md
+++ b/RELEASE_GUIDELINES.md
@@ -1,7 +1,7 @@
 # Release Guidelines for the CaosDB Python Client Library
 
 This document specifies release guidelines in addition to the general release
-guidelines of the CaosDB Project
+guidelines of the LinkAhead project
 ([RELEASE_GUIDELINES.md](https://gitlab.com/caosdb/caosdb/blob/dev/RELEASE_GUIDELINES.md))
 
 ## General Prerequisites
diff --git a/extra/emacs/snippets/yaml-mode/RecordType b/extra/emacs/snippets/yaml-mode/RecordType
index 6b4a9c26..8c0382d5 100644
--- a/extra/emacs/snippets/yaml-mode/RecordType
+++ b/extra/emacs/snippets/yaml-mode/RecordType
@@ -1,5 +1,5 @@
 # -*- mode: snippet -*-
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/integrationtests/insert_model.py b/integrationtests/insert_model.py
index 26bf478c..170adbc8 100755
--- a/integrationtests/insert_model.py
+++ b/integrationtests/insert_model.py
@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-import caosdb as db
+import linkahead as db
 import h5py
 from caosadvancedtools.cfoods.h5 import H5CFood
 from caosadvancedtools.models.data_model import DataModel
diff --git a/integrationtests/insert_some.py b/integrationtests/insert_some.py
index cf16a45d..19a4c1f2 100644
--- a/integrationtests/insert_some.py
+++ b/integrationtests/insert_some.py
@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.scifolder.experiment_cfood import dm
 
 # This inserts two identifiables. When no dependencies are possible among
diff --git a/integrationtests/test_data_model.py b/integrationtests/test_data_model.py
index bd74a40b..bde9eda9 100644
--- a/integrationtests/test_data_model.py
+++ b/integrationtests/test_data_model.py
@@ -1,7 +1,7 @@
 import unittest
 import pytest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.models.data_model import DataModel
 
 
diff --git a/integrationtests/test_im_und_export.py b/integrationtests/test_im_und_export.py
index 407faa1a..5d0aa26b 100644
--- a/integrationtests/test_im_und_export.py
+++ b/integrationtests/test_im_und_export.py
@@ -2,7 +2,7 @@
 import os
 from tempfile import TemporaryDirectory
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.export_related import export_related_to
 from caosadvancedtools.import_from_xml import import_xml
 
@@ -19,7 +19,7 @@ if __name__ == "__main__":
     assert 0 == len(db.execute_query("FIND File which is stored at "
                                      "**/poster.pdf"))
     print("Importing stored elements")
-    import_xml(os.path.join(directory.name, "caosdb_data.xml"), interactive=False)
+    import_xml(os.path.join(directory.name, "linkahead_data.xml"), interactive=False)
 
     # The following tests the existence of some required entities.
     # However, this is not a full list.
diff --git a/integrationtests/test_json_schema_exporter.py b/integrationtests/test_json_schema_exporter.py
index 44b42826..5b0d758e 100644
--- a/integrationtests/test_json_schema_exporter.py
+++ b/integrationtests/test_json_schema_exporter.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2023 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2023 Florian Spreckelsen <f.spreckelsen@indiscale.com>
diff --git a/manual_tests/test_labfolder_import.py b/manual_tests/test_labfolder_import.py
index c767feb5..abc5eb11 100644
--- a/manual_tests/test_labfolder_import.py
+++ b/manual_tests/test_labfolder_import.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (c) 2020 IndiScale GmbH
 # Copyright (c) 2020 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/manual_tests/test_labfolder_retrieve.py b/manual_tests/test_labfolder_retrieve.py
index 5bbaf91d..a7f56e80 100644
--- a/manual_tests/test_labfolder_retrieve.py
+++ b/manual_tests/test_labfolder_retrieve.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (c) 2020 IndiScale GmbH
 #
diff --git a/setup.py b/setup.py
index bee11751..a7146ead 100755
--- a/setup.py
+++ b/setup.py
@@ -149,7 +149,7 @@ def setup_package():
     metadata = dict(
         name='caosadvancedtools',
         version=get_version_info()[0],
-        description='advanced utilities for caosdb',
+        description='Advanced utilities for LinkAhead',
         long_description=long_description,
         long_description_content_type="text/markdown",
         author='Henrik tom Wörden',
diff --git a/src/caosadvancedtools/cfoods/__init__.py b/src/caosadvancedtools/cfoods/__init__.py
index 30ce05ad..6936568a 100644
--- a/src/caosadvancedtools/cfoods/__init__.py
+++ b/src/caosadvancedtools/cfoods/__init__.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH <www.indiscale.com>
 # Copyright (C) 2020 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/src/caosadvancedtools/datainconsistency.py b/src/caosadvancedtools/datainconsistency.py
index 3af8b5a2..9931dd68 100644
--- a/src/caosadvancedtools/datainconsistency.py
+++ b/src/caosadvancedtools/datainconsistency.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Henrik tom Wörden <h.tomwoerden@indiscale.com>
diff --git a/src/caosadvancedtools/json_schema_exporter.py b/src/caosadvancedtools/json_schema_exporter.py
index c4c6de16..5daa5a4e 100644
--- a/src/caosadvancedtools/json_schema_exporter.py
+++ b/src/caosadvancedtools/json_schema_exporter.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2023 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2023 Florian Spreckelsen <f.spreckelsen@indiscale.com>
diff --git a/src/caosadvancedtools/pandoc_header_tools.py b/src/caosadvancedtools/pandoc_header_tools.py
index e746a26a..e0e62c8c 100644
--- a/src/caosadvancedtools/pandoc_header_tools.py
+++ b/src/caosadvancedtools/pandoc_header_tools.py
@@ -6,7 +6,7 @@
 # A. Schlemmer, 04/2019
 
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
diff --git a/src/caosadvancedtools/read_md_header.py b/src/caosadvancedtools/read_md_header.py
index ece81c40..cc3e2152 100644
--- a/src/caosadvancedtools/read_md_header.py
+++ b/src/caosadvancedtools/read_md_header.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C)
 # A. Schlemmer, 01/2019
@@ -34,7 +34,7 @@ def get_header(fn):
 # import os
 # import re
 
-# import caosdb as db
+# import linkahead as db
 # import yaml
 
 # from .cfood import AbstractCFood, get_entity
diff --git a/src/caosadvancedtools/scifolder/experiment_cfood.py b/src/caosadvancedtools/scifolder/experiment_cfood.py
index 83329863..b19b2924 100644
--- a/src/caosadvancedtools/scifolder/experiment_cfood.py
+++ b/src/caosadvancedtools/scifolder/experiment_cfood.py
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      assure_has_property,
                                      assure_object_is_in_list,
diff --git a/src/caosadvancedtools/scifolder/publication_cfood.py b/src/caosadvancedtools/scifolder/publication_cfood.py
index 68e345ac..61e0a0ef 100644
--- a/src/caosadvancedtools/scifolder/publication_cfood.py
+++ b/src/caosadvancedtools/scifolder/publication_cfood.py
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      assure_object_is_in_list, fileguide,
                                      )
diff --git a/src/caosadvancedtools/scifolder/result_table_cfood.py b/src/caosadvancedtools/scifolder/result_table_cfood.py
index e32cd0bd..fec29039 100644
--- a/src/caosadvancedtools/scifolder/result_table_cfood.py
+++ b/src/caosadvancedtools/scifolder/result_table_cfood.py
@@ -18,7 +18,7 @@
 
 import re
 
-import caosdb as db
+import linkahead as db
 import pandas as pd
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      )
diff --git a/src/caosadvancedtools/scifolder/simulation_cfood.py b/src/caosadvancedtools/scifolder/simulation_cfood.py
index f8f3d07e..5127cbfd 100644
--- a/src/caosadvancedtools/scifolder/simulation_cfood.py
+++ b/src/caosadvancedtools/scifolder/simulation_cfood.py
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      assure_has_property,
                                      assure_object_is_in_list,
diff --git a/src/caosadvancedtools/scifolder/software_cfood.py b/src/caosadvancedtools/scifolder/software_cfood.py
index d91817f1..589112c5 100644
--- a/src/caosadvancedtools/scifolder/software_cfood.py
+++ b/src/caosadvancedtools/scifolder/software_cfood.py
@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      assure_has_property, assure_name_is,
                                      assure_object_is_in_list,
diff --git a/src/caosadvancedtools/scifolder/utils.py b/src/caosadvancedtools/scifolder/utils.py
index cbf87c4b..8e832c10 100644
--- a/src/caosadvancedtools/scifolder/utils.py
+++ b/src/caosadvancedtools/scifolder/utils.py
@@ -21,7 +21,7 @@ import logging
 import os
 from itertools import chain
 
-import caosdb as db
+import linkahead as db
 import pandas as pd
 from caosadvancedtools.cfood import assure_object_is_in_list, fileguide
 from caosadvancedtools.utils import (find_records_that_reference_ids,
diff --git a/src/caosadvancedtools/scifolder/withreadme.py b/src/caosadvancedtools/scifolder/withreadme.py
index d8388e1d..94280b80 100644
--- a/src/caosadvancedtools/scifolder/withreadme.py
+++ b/src/caosadvancedtools/scifolder/withreadme.py
@@ -22,7 +22,7 @@ import logging
 import os
 from dataclasses import dataclass
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (assure_has_description, assure_has_parent,
                                      assure_object_is_in_list, fileguide)
 from caosadvancedtools.read_md_header import get_header as get_md_header
diff --git a/src/caosadvancedtools/serverside/generic_analysis.py b/src/caosadvancedtools/serverside/generic_analysis.py
index 7c7b26cc..e32e02d0 100644
--- a/src/caosadvancedtools/serverside/generic_analysis.py
+++ b/src/caosadvancedtools/serverside/generic_analysis.py
@@ -87,8 +87,8 @@ import logging
 import os
 import sys
 
-import caosdb as db
-from caosdb.utils.server_side_scripting import run_server_side_script
+import linkahead as db
+from linkahead.utils.server_side_scripting import run_server_side_script
 
 logger = logging.getLogger(__name__)
 
diff --git a/src/doc/Makefile b/src/doc/Makefile
index 7a1bec10..2df1aff8 100644
--- a/src/doc/Makefile
+++ b/src/doc/Makefile
@@ -1,5 +1,5 @@
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/src/doc/crawler.rst b/src/doc/crawler.rst
index d7b351bb..3323631e 100644
--- a/src/doc/crawler.rst
+++ b/src/doc/crawler.rst
@@ -241,7 +241,7 @@ Let’s look at the following Example:
 
    >>> # Example CFood
    >>> from caosadvancedtools.cfood import AbstractFileCFood, assure_has_property
-   >>> import caosdb as db
+   >>> import linkahead as db
    >>> 
    >>> class ExampleCFood(AbstractFileCFood):
    ...     @staticmethod
diff --git a/unittests/create_filetree.py b/unittests/create_filetree.py
index f80b9681..bbd7783c 100644
--- a/unittests/create_filetree.py
+++ b/unittests/create_filetree.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
diff --git a/unittests/test_caosdbignore.py b/unittests/test_caosdbignore.py
index 9394bf0c..c044a8e8 100644
--- a/unittests/test_caosdbignore.py
+++ b/unittests/test_caosdbignore.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -34,12 +34,12 @@ from caosadvancedtools.loadFiles import compile_file_list, create_re_for_file_li
 BASEDIR = os.path.dirname(os.path.realpath(__file__))
 
 
-class Caosdbignore(unittest.TestCase):
+class Linkaheadignore(unittest.TestCase):
     def setUp(self):
         pass
 
     def test_compile(self):
-        files = compile_file_list(os.path.join(BASEDIR, "caosdbignore-example"),
+        files = compile_file_list(os.path.join(BASEDIR, "linkaheadignore-example"),
                                   os.path.join(BASEDIR, "data"))
         assert len(files) == 3
         assert os.path.join(BASEDIR, "data", "datatypes.xlsx") in files
diff --git a/unittests/test_data_model.py b/unittests/test_data_model.py
index cafeb6ca..354e0bf6 100644
--- a/unittests/test_data_model.py
+++ b/unittests/test_data_model.py
@@ -1,6 +1,6 @@
 import unittest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.models.data_model import DataModel
 from caosadvancedtools.models.parser import parse_model_from_string
 
diff --git a/unittests/test_json_schema_exporter.py b/unittests/test_json_schema_exporter.py
index 1cea2f58..fd6dbf7c 100644
--- a/unittests/test_json_schema_exporter.py
+++ b/unittests/test_json_schema_exporter.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2023 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2023 Florian Spreckelsen <f.spreckelsen@indiscale.com>
diff --git a/unittests/test_sss_helper.py b/unittests/test_sss_helper.py
index 71408fa6..c040f503 100644
--- a/unittests/test_sss_helper.py
+++ b/unittests/test_sss_helper.py
@@ -3,13 +3,13 @@ from email import message_from_file, policy
 from os import listdir, remove
 from os.path import abspath, dirname, exists, isfile, join
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.serverside.helper import (NameCollector, get_data,
                                                  get_file_via_download,
                                                  init_data_model,
                                                  parse_arguments, send_mail)
-from caosdb import RecordType, configure_connection, get_config
-from caosdb.connection.mockup import MockUpResponse, MockUpServerConnection
+from linkahead import RecordType, configure_connection, get_config
+from linkahead.connection.mockup import MockUpResponse, MockUpServerConnection
 from pytest import mark, raises
 
 
@@ -110,8 +110,8 @@ def test_get_file_via_download():
     # TODO test whether something ends up in the logger
     class NotThere(DummyFile):
         def download(*args, **kwargs):
-            raise db.CaosDBException()
-    with raises(db.CaosDBException):
+            raise db.LinkAheadException()
+    with raises(db.LinkAheadException):
         get_file_via_download(Inconsistent())
 
 
diff --git a/unittests/test_suppressKnown.py b/unittests/test_suppressKnown.py
index 07c2e18e..6f87e842 100644
--- a/unittests/test_suppressKnown.py
+++ b/unittests/test_suppressKnown.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH
 # Copyright (C) 2020 Henrik tom Wörden
diff --git a/unittests/test_yaml_model_parser.py b/unittests/test_yaml_model_parser.py
index 9ca92a1d..f8e27507 100644
--- a/unittests/test_yaml_model_parser.py
+++ b/unittests/test_yaml_model_parser.py
@@ -1,4 +1,4 @@
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2023 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2023 Daniel Hornung <d.hornung@indiscale.com>
diff --git a/integrationtests/clear_database.py b/integrationtests/clear_database.py
index 138cf4e6..b0b5020f 100644
--- a/integrationtests/clear_database.py
+++ b/integrationtests/clear_database.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -23,7 +23,7 @@
 # ** end header
 #
 """Clear the database before and after the integration tests."""
-import caosdb as db
+import linkahead as db
 
 
 def clear_all():
@@ -1,7 +1,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/integrationtests/crawl.py b/integrationtests/crawl.py
index defed2cb..a3e43a19 100755
--- a/integrationtests/crawl.py
+++ b/integrationtests/crawl.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -28,7 +28,7 @@ import logging
 import sys
 from argparse import RawTextHelpFormatter
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import fileguide
 from caosadvancedtools.crawler import FileCrawler
 from caosadvancedtools.guard import INSERT, UPDATE
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/integrationtests/create_analysis.py b/integrationtests/create_analysis.py
index 1b7aa0d2..ec2c707c 100644
--- a/integrationtests/create_analysis.py
+++ b/integrationtests/create_analysis.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -31,7 +31,7 @@ automated analysis pipeline.
 import sys
 from datetime import datetime
 
-import caosdb as db
+import linkahead as db
 
 
 def main():
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
diff --git a/integrationtests/example_hdf5cfood.py b/integrationtests/example_hdf5cfood.py
index 5485402d..73688581 100644
--- a/integrationtests/example_hdf5cfood.py
+++ b/integrationtests/example_hdf5cfood.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -27,7 +27,7 @@
 An exemplary definition of a HDF5 CFood for integration testing
 """
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfoods.h5 import H5CFood
 from caosadvancedtools.scifolder import ExperimentCFood
 from caosadvancedtools.scifolder.generic_pattern import readme_pattern
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
diff --git a/integrationtests/test_assure_functions.py b/integrationtests/test_assure_functions.py
index e04d481f..91ec1440 100644
--- a/integrationtests/test_assure_functions.py
+++ b/integrationtests/test_assure_functions.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2021 University Medical Center Göttingen, Institute for Medical Informatics
@@ -25,7 +25,7 @@
 no `to_be_updated` is specified.
 
 """
-import caosdb as db
+import linkahead as db
 
 from caosadvancedtools.cfood import (assure_object_is_in_list)
 from caosadvancedtools.guard import (global_guard, RETRIEVE, UPDATE)
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_base_table_exporter_integration.py b/integrationtests/test_base_table_exporter_integration.py
index 5af9caa3..286c4ac3 100644
--- a/integrationtests/test_base_table_exporter_integration.py
+++ b/integrationtests/test_base_table_exporter_integration.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Sprecklelsen <f.spreckelsen@indiscale.com>
@@ -22,7 +22,7 @@
 #
 # ** end header
 #
-import caosdb as db
+import linkahead as db
 import pytest
 from caosadvancedtools import table_export as te
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_cache.py b/integrationtests/test_cache.py
index aacef179..13470b8b 100644
--- a/integrationtests/test_cache.py
+++ b/integrationtests/test_cache.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -26,7 +26,7 @@ import os
 import unittest
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cache import UpdateCache
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_crawl_with_datamodel_problems.py b/integrationtests/test_crawl_with_datamodel_problems.py
index 8623d57d..c2b19a95 100644
--- a/integrationtests/test_crawl_with_datamodel_problems.py
+++ b/integrationtests/test_crawl_with_datamodel_problems.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (c) 2020 IndiScale GmbH <info@indiscale.com>
 # Copyright (c) 2020 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -25,7 +25,7 @@
 
 """
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools import loadFiles
 from caosadvancedtools.cfood import fileguide
 from caosadvancedtools.crawler import FileCrawler
@@ -1,7 +1,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (c) 2020 IndiScale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_crawler_basics.py b/integrationtests/test_crawler_basics.py
index 60c09d73..04eb5459 100644
--- a/integrationtests/test_crawler_basics.py
+++ b/integrationtests/test_crawler_basics.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -29,7 +29,7 @@ cfoods. This is tested in test_crawler_with_cfoods.py.
 """
 import unittest
 
-import caosdb as db
+import linkahead as db
 
 from caosadvancedtools.crawler import Crawler
 from caosadvancedtools.guard import INSERT
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/integrationtests/test_crawler_with_cfoods.py b/integrationtests/test_crawler_with_cfoods.py
index 1fa5eaa5..472eee0e 100755
--- a/integrationtests/test_crawler_with_cfoods.py
+++ b/integrationtests/test_crawler_with_cfoods.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -25,8 +25,8 @@
 import os
 import unittest
 
-import caosdb as db
-from caosdb.apiutils import retrieve_entity_with_id
+import linkahead as db
+from linkahead.apiutils import retrieve_entity_with_id
 
 
 def get_entity_with_id(eid):
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/integrationtests/test_datamodel_problems.py b/integrationtests/test_datamodel_problems.py
index 85517033..1ac32bb8 100644
--- a/integrationtests/test_datamodel_problems.py
+++ b/integrationtests/test_datamodel_problems.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -27,10 +27,10 @@ during crawling that tests the integrations of the DataModelProblems
 class in crawler.py and cfood.py can be found in full-tests.
 
 """
-import caosdb as db
+import linkahead as db
 import pytest
 from caosadvancedtools.datamodel_problems import DataModelProblems
-from caosdb.exceptions import (TransactionError,
+from linkahead.exceptions import (TransactionError,
                                UnqualifiedParentsError,
                                UnqualifiedPropertiesError)
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_json_schema_datamodel_parser.py b/integrationtests/test_json_schema_datamodel_parser.py
index 21ae8d2d..074c4a06 100644
--- a/integrationtests/test_json_schema_datamodel_parser.py
+++ b/integrationtests/test_json_schema_datamodel_parser.py
@@ -1,5 +1,5 @@
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -20,7 +20,7 @@
 
 import os
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.models.parser import parse_model_from_json_schema
 
 
@@ -1,5 +1,5 @@
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
diff --git a/integrationtests/test_table.py b/integrationtests/test_table.py
index b8dfe349..4e87a7db 100644
--- a/integrationtests/test_table.py
+++ b/integrationtests/test_table.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
 #
@@ -20,7 +20,7 @@
 
 import logging
 
-import caosdb as db
+import linkahead as db
 import pandas as pd
 
 from caosadvancedtools.crawler import TableCrawler
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
diff --git a/integrationtests/test_yaml_parser.py b/integrationtests/test_yaml_parser.py
index e2a2c4c0..9718c4a2 100644
--- a/integrationtests/test_yaml_parser.py
+++ b/integrationtests/test_yaml_parser.py
@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -19,7 +19,7 @@
 # with this program. If not, see <https://www.gnu.org/licenses/>.
 #
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.models.parser import parse_model_from_string
 
 
@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
diff --git a/integrationtests/update_analysis.py b/integrationtests/update_analysis.py
index ddebc049..18ae8332 100644
--- a/integrationtests/update_analysis.py
+++ b/integrationtests/update_analysis.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -34,7 +34,7 @@ entities that where changed within a certain period of time.
 
 import sys
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.serverside.generic_analysis import run
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
diff --git a/src/caosadvancedtools/cache.py b/src/caosadvancedtools/cache.py
index bf1287ba..749239fa 100644
--- a/src/caosadvancedtools/cache.py
+++ b/src/caosadvancedtools/cache.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -33,7 +33,7 @@ from abc import ABC, abstractmethod
 from copy import deepcopy
 from hashlib import sha256
 
-import caosdb as db
+import linkahead as db
 from lxml import etree
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/src/caosadvancedtools/cfood.py b/src/caosadvancedtools/cfood.py
index 588476bd..e79f0373 100644
--- a/src/caosadvancedtools/cfood.py
+++ b/src/caosadvancedtools/cfood.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -23,9 +23,9 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 """ Defines how something that shall be inserted into CaosDB is treated.
 
-CaosDB can automatically be filled with Records based on some structure, a file
+LinkAhead can automatically be filled with Records based on some structure, a file
 structure, a table or similar.
 
 The Crawler will iterate over the respective items and test for each item
@@ -33,9 +33,9 @@ whether a CFood class exists that matches the file path, i.e. whether CFood
 class wants to treat that pariticular item. If one does, it is instanciated to
 treat the match. This occurs in basically three steps:
 
-1. Create a list of identifiables, i.e. unique representation of CaosDB Records
+1. Create a list of identifiables, i.e. unique representation of LinkAhead Records
    (such as an experiment belonging to a project and a date/time).
-2. The identifiables are either found in CaosDB or they are created.
+2. The identifiables are either found in LinkAhead or they are created.
 3. The identifiables are update based on the date in the file structure.
 """
 
@@ -45,10 +45,10 @@ import warnings
 from abc import ABCMeta, abstractmethod
 from datetime import datetime
 
-import caosdb as db
-from caosdb.common.models import Entity
-from caosdb.exceptions import (BadQueryError, EmptyUniqueQueryError,
-                               QueryNotUniqueError, TransactionError)
+import linkahead as db
+from linkahead.common.models import Entity
+from linkahead.exceptions import (BadQueryError, EmptyUniqueQueryError,
+                                  QueryNotUniqueError, TransactionError)
 
 from .datamodel_problems import DataModelProblems
 from .guard import global_guard as guard
@@ -65,7 +65,7 @@ logger = logging.getLogger(__name__)
 def get_entity(name):
     """ Returns the entity with a given name, preferably from a local cache.
 
     If the local cache does not contain the entity, retrieve it from CaosDB.
     """
 
     if name not in ENTITIES:
@@ -81,7 +81,7 @@ def get_property(name):
     cache.
 
     If the local cache does not contain the record type, try to
     retrieve it from CaosDB. If it does not exist, see whether it
     could be a record type used as a property.
 
     """
@@ -103,7 +103,7 @@ def get_record(name):
     """Returns the record with a given name, preferably from a local cache.
 
     If the local cache does not contain the record, try to retrieve it
-    from CaosDB.
+    from LinkAhead.
 
     """
 
@@ -120,7 +120,7 @@ def get_recordtype(name):
     cache.
 
     If the local cache does not contain the record type, try to
     retrieve it from CaosDB. If it does not exist, add it to the data
     model problems
 
     """
@@ -140,7 +140,7 @@ def get_recordtype(name):
 class FileGuide(object):
     def access(self, path):
         """ should be replaced by a function that adds
         a prefix to paths to allow to access caosdb files locally
 
         This default just returns the unchanged path.
         """
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
@@ -23,9 +23,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
-""" Defines how something that shall be inserted into CaosDB is treated.
+""" Defines how something that shall be inserted into LinkAhead is treated.
 
@@ -65,7 +65,7 @@ logger = logging.getLogger(__name__)
     """ Returns the entity with a given name, preferably from a local cache.
 
-    If the local cache does not contain the entity, retrieve it from CaosDB.
+    If the local cache does not contain the entity, retrieve it from LinkAhead.
     """
 
@@ -81,7 +81,7 @@ def get_property(name):
 
     If the local cache does not contain the record type, try to
-    retrieve it from CaosDB. If it does not exist, see whether it
+    retrieve it from LinkAhead. If it does not exist, see whether it
     could be a record type used as a property.
 
@@ -120,7 +120,7 @@ def get_recordtype(name):
 
     If the local cache does not contain the record type, try to
-    retrieve it from CaosDB. If it does not exist, add it to the data
+    retrieve it from LinkAhead. If it does not exist, add it to the data
     model problems
 
@@ -140,7 +140,7 @@ def get_recordtype(name):
     def access(self, path):
         """ should be replaced by a function that adds
-        a prefix to paths to allow to access caosdb files locally
+        a prefix to paths to allow to access LinkAhead files locally
 
         This default just returns the unchanged path.
diff --git a/src/caosadvancedtools/cfoods/h5.py b/src/caosadvancedtools/cfoods/h5.py
index dfd6f290..3b3b5688 100644
--- a/src/caosadvancedtools/cfoods/h5.py
+++ b/src/caosadvancedtools/cfoods/h5.py
@@ -34,7 +34,7 @@ Properties.
 
 from copy import deepcopy
 
-import caosdb as db
+import linkahead as db
 import h5py
 import numpy as np
 from caosadvancedtools.cfood import fileguide
@@ -45,7 +45,7 @@ from ..structure_mapping import (EntityMapping, collect_existing_structure,
 
 
 def h5_attr_to_property(val):
     """ returns the value and datatype of a CaosDB Property for the given value
 
 
     1d arrays are converted to lists
@@ -168,7 +168,7 @@ class H5CFood(AbstractFileCFood):
         self.to_be_inserted = db.Container()
         self.insert_missing_structure(self.structure)
 
         # TODO this is a workaround due to the fact that the caosdb library
         # changes the objects in the Container if it is inserted. The graph
         # structure is flattened. I.e. references to other entity objects are
         # replaced with their IDs. However this code depends on this graph.
@@ -45,7 +45,7 @@ from ..structure_mapping import (EntityMapping, collect_existing_structure,
 
 def h5_attr_to_property(val):
-    """ returns the value and datatype of a CaosDB Property for the given value
+    """ returns the value and datatype of a LinkAhead Property for the given value
 
 
@@ -168,7 +168,7 @@ class H5CFood(AbstractFileCFood):
         self.insert_missing_structure(self.structure)
 
-        # TODO this is a workaround due to the fact that the caosdb library
+        # TODO this is a workaround due to the fact that the linkahead library
         # changes the objects in the Container if it is inserted. The graph
         # structure is flattened. I.e. references to other entity objects are
diff --git a/src/caosadvancedtools/collect_datamodel.py b/src/caosadvancedtools/collect_datamodel.py
index 806d1533..1c37bab0 100644
--- a/src/caosadvancedtools/collect_datamodel.py
+++ b/src/caosadvancedtools/collect_datamodel.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -25,8 +25,8 @@
 import argparse
 import os
 
-import caosdb as db
-from caosdb.apiutils import retrieve_entities_with_ids
+import linkahead as db
+from linkahead.apiutils import retrieve_entities_with_ids
 
 from export_related import export
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/src/caosadvancedtools/converter/labfolder_api.py b/src/caosadvancedtools/converter/labfolder_api.py
index cf57c015..fe77282a 100644
--- a/src/caosadvancedtools/converter/labfolder_api.py
+++ b/src/caosadvancedtools/converter/labfolder_api.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (c) 2020 IndiScale GmbH
 # Copyright (c) 2020 Daniel Hornung <d.hornung@indiscale.com>
@@ -27,7 +27,7 @@ import time
 
 import html2text
 
-import caosdb as db
+import linkahead as db
 from labfolder.connection import configure_connection  # pylint: disable=import-error
 
 
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (c) 2020 IndiScale GmbH
diff --git a/src/caosadvancedtools/converter/labfolder_export.py b/src/caosadvancedtools/converter/labfolder_export.py
index 6e282218..ae38cb10 100644
--- a/src/caosadvancedtools/converter/labfolder_export.py
+++ b/src/caosadvancedtools/converter/labfolder_export.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (c) 2020 IndiScale GmbH
 # Copyright (c) 2020 Daniel Hornung <d.hornung@indiscale.com>
@@ -25,7 +25,7 @@ import os
 
 from bs4 import BeautifulSoup
 
-import caosdb as db
+import linkahead as db
 
 RERUN = False
 # crawler = Crawler()
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (c) 2020 IndiScale GmbH
diff --git a/src/caosadvancedtools/crawler.py b/src/caosadvancedtools/crawler.py
index fc3b260b..7a840624 100644
--- a/src/caosadvancedtools/crawler.py
+++ b/src/caosadvancedtools/crawler.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -25,16 +25,16 @@
 #
 # ** end header
 #
 """ Crawls a file structure and inserts Records into CaosDB based on what is
 found.
 
-CaosDB can automatically be filled with Records based on some file structure.
+LinkAhead can automatically be filled with Records based on some file structure.
 The Crawler will iterate over the files and test for each file whether a CFood
 exists that matches the file path. If one does, it is instanciated to treat the
 match. This occurs in basically three steps:
-1. create a list of identifiables, i.e. unique representation of CaosDB Records
+1. create a list of identifiables, i.e. unique representation of LinkAhead Records
 (such as an experiment belonging to a project and a date/time)
-2. the identifiables are either found in CaosDB or they are created.
+2. the identifiables are either found in LinkAhead or they are created.
 3. the identifiables are update based on the date in the file structure
 """
 
@@ -47,8 +47,8 @@ import uuid
 from datetime import datetime
 from sqlite3 import IntegrityError
 
-import caosdb as db
-from caosdb.exceptions import BadQueryError
+import linkahead as db
+from linkahead.exceptions import BadQueryError
 
 from .cache import IdentifiableCache, UpdateCache, get_pretty_xml
 from .cfood import RowCFood, add_files, get_ids_for_entities_with_names
@@ -69,7 +69,7 @@ def separated(text):
 
 def apply_list_of_updates(to_be_updated, update_flags={},
                           update_cache=None, run_id=None):
-    """Updates the `to_be_updated` Container, i.e., pushes the changes to CaosDB
+    """Updates the `to_be_updated` Container, i.e., pushes the changes to LinkAhead
     after removing possible duplicates. If a chace is provided, uauthorized
     updates can be cached for further authorization.
 
@@ -78,7 +78,7 @@ def apply_list_of_updates(to_be_updated, update_flags={},
     to_be_updated : db.Container
         Container with the entities that will be updated.
     update_flags : dict, optional
         Dictionary of CaosDB server flags that will be used for the
         update. Default is an empty dict.
     update_cache : UpdateCache or None, optional
         Cache in which the intended updates will be stored so they can be
@@ -147,7 +147,7 @@ class Crawler(object):
                The Crawler will use those CFoods when crawling.
         use_cache : bool, optional
                     Whether to use caching (not re-inserting probably existing
-                    objects into CaosDB), defaults to False.
+                    objects into LinkAhead), defaults to False.
         abort_on_exception : if true, exceptions are raise.
                     Otherwise the crawler continues if an exception occurs.
         interactive : boolean, optional
@@ -271,7 +271,7 @@ class Crawler(object):
         """
         This is the first phase of the crawl. It collects all cfoods that shall
         be processed. The second phase is iterating over cfoods and updating
         CaosDB. This separate first step is necessary in order to allow a
         single cfood being influenced by multiple crawled items. E.g. the
         FileCrawler can have a single cfood treat multiple files.
 
@@ -512,16 +512,16 @@ ____________________\n""".format(i+1, len(pending_changes)) + str(el[3]))
 
         Parameters:
         -----------
         changes: The CaosDB entities in the version after the update.
         path: the path defining the subtree that is crawled
 
         """
         from xml.sax.saxutils import escape
 
-        caosdb_config = db.configuration.get_config()
-        if ("advancedtools" in caosdb_config and "crawler.customcssfile" in
-                caosdb_config["advancedtools"]):
-            cssfile = caosdb_config["advancedtools"]["crawler.customcssfile"]
+        linkahead_config = db.configuration.get_config()
+        if ("advancedtools" in linkahead_config and "crawler.customcssfile" in
+                linkahead_config["advancedtools"]):
+            cssfile = linkahead_config["advancedtools"]["crawler.customcssfile"]
         else:
             cssfile = None
         # TODO move path related stuff to sss_helper
@@ -584,11 +584,11 @@ ____________________\n""".format(i+1, len(pending_changes)) + str(el[3]))
     </script>
 </body>
 </html>
-""".format(url=caosdb_config["Connection"]["url"],
+""".format(url=linkahead_config["Connection"]["url"],
            rid=run_id,
            changes=escape("\n".join(changes)),
            customcssfile='<link rel="stylesheet" href="{url}/webinterface/css/{customcssfile}"/>'.format(
-               url=caosdb_config["Connection"]["url"], customcssfile=cssfile) if cssfile else "",
+               url=linkahead_config["Connection"]["url"], customcssfile=cssfile) if cssfile else "",
            path=path)
 
         if "SHARED_DIR" in os.environ:
@@ -611,11 +611,11 @@ ____________________\n""".format(i+1, len(pending_changes)) + str(el[3]))
 
         Parameters:
         -----------
         changes: The CaosDB entities in the version after the update.
         filename: path to the html site that allow the authorization
         """
 
-        caosdb_config = db.configuration.get_config()
+        linkahead_config = db.configuration.get_config()
         text = """Dear Curator,
 there where changes that need your authorization. Please check the following
 carefully and if the changes are ok, click on the following link:
@@ -623,12 +623,12 @@ carefully and if the changes are ok, click on the following link:
 {url}/Shared/{filename}
 
 {changes}
-        """.format(url=caosdb_config["Connection"]["url"],
+        """.format(url=linkahead_config["Connection"]["url"],
                    filename=filename,
                    changes="\n".join(changes))
         try:
-            fro = caosdb_config["advancedtools"]["crawler.from_mail"]
-            to = caosdb_config["advancedtools"]["crawler.to_mail"]
+            fro = linkahead_config["advancedtools"]["crawler.from_mail"]
+            to = linkahead_config["advancedtools"]["crawler.to_mail"]
         except KeyError:
             logger.error("Server Configuration is missing a setting for "
                          "sending mails. The administrator should check "
@@ -646,11 +646,11 @@ carefully and if the changes are ok, click on the following link:
     @staticmethod
     def find_or_insert_identifiables(identifiables):
         """ Sets the ids of identifiables (that do not have already an id from the
         cache) based on searching CaosDB and retrieves those entities.
         The remaining entities (those which can not be retrieved) have no
         correspondence in CaosDB and are thus inserted.
         """
         # looking for matching entities in CaosDB when there is no valid id
         # i.e. there was none set from a cache
 
         existing = []
@@ -699,7 +699,7 @@ carefully and if the changes are ok, click on the following link:
         else:
             logger.debug("Did not insert any new entities")
 
-        logger.debug("Retrieving entities from CaosDB...")
+        logger.debug("Retrieving entities from LinkAhead...")
         identifiables.retrieve(unique=True, raise_exception_on_error=False)
 
     @staticmethod
@@ -735,7 +735,7 @@ carefully and if the changes are ok, click on the following link:
 
     @staticmethod
     def find_existing(entity):
         """searches for an entity that matches the identifiable in CaosDB
 
         Characteristics of the identifiable like, properties, name or id are
         used for the match.
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
@@ -25,16 +25,16 @@
 # ** end header
 #
-""" Crawls a file structure and inserts Records into CaosDB based on what is
+""" Crawls a file structure and inserts Records into LinkAhead based on what is
 found.
 
@@ -78,7 +78,7 @@ def apply_list_of_updates(to_be_updated, update_flags={},
         Container with the entities that will be updated.
     update_flags : dict, optional
-        Dictionary of CaosDB server flags that will be used for the
+        Dictionary of LinkAhead server flags that will be used for the
         update. Default is an empty dict.
     update_cache : UpdateCache or None, optional
@@ -271,7 +271,7 @@ class Crawler(object):
         This is the first phase of the crawl. It collects all cfoods that shall
         be processed. The second phase is iterating over cfoods and updating
-        CaosDB. This separate first step is necessary in order to allow a
+        LinkAhead. This separate first step is necessary in order to allow a
         single cfood being influenced by multiple crawled items. E.g. the
         FileCrawler can have a single cfood treat multiple files.
@@ -512,16 +512,16 @@ ____________________\n""".format(i+1, len(pending_changes)) + str(el[3]))
         Parameters:
         -----------
-        changes: The CaosDB entities in the version after the update.
+        changes: The LinkAhead entities in the version after the update.
         path: the path defining the subtree that is crawled
 
@@ -611,11 +611,11 @@ ____________________\n""".format(i+1, len(pending_changes)) + str(el[3]))
         Parameters:
         -----------
-        changes: The CaosDB entities in the version after the update.
+        changes: The LinkAhead entities in the version after the update.
         filename: path to the html site that allow the authorization
         """
@@ -646,11 +646,11 @@ carefully and if the changes are ok, click on the following link:
     def find_or_insert_identifiables(identifiables):
         """ Sets the ids of identifiables (that do not have already an id from the
-        cache) based on searching CaosDB and retrieves those entities.
+        cache) based on searching LinkAhead and retrieves those entities.
         The remaining entities (those which can not be retrieved) have no
@@ -646,11 +646,11 @@ carefully and if the changes are ok, click on the following link:
         The remaining entities (those which can not be retrieved) have no
-        correspondence in CaosDB and are thus inserted.
+        correspondence in LinkAhead and are thus inserted.
         """
@@ -646,11 +646,11 @@ carefully and if the changes are ok, click on the following link:
         """
-        # looking for matching entities in CaosDB when there is no valid id
+        # looking for matching entities in LinkAhead when there is no valid id
         # i.e. there was none set from a cache
 
@@ -735,7 +735,7 @@ carefully and if the changes are ok, click on the following link:
     @staticmethod
     def find_existing(entity):
-        """searches for an entity that matches the identifiable in CaosDB
+        """searches for an entity that matches the identifiable in LinkAhead
 
         Characteristics of the identifiable like, properties, name or id are
diff --git a/src/caosadvancedtools/datamodel_problems.py b/src/caosadvancedtools/datamodel_problems.py
index df5b7e56..07fef07b 100644
--- a/src/caosadvancedtools/datamodel_problems.py
+++ b/src/caosadvancedtools/datamodel_problems.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Sprckelsen <f.spreckelsen@indiscale.com>
@@ -27,7 +27,7 @@ be inserted by hand or gueesed from possible exceptions when inserting
 or updating entities with missing parents and/or properties.
 
 """
-from caosdb.exceptions import (EntityDoesNotExistError,
+from linkahead.exceptions import (EntityDoesNotExistError,
                                TransactionError,
                                UnqualifiedParentsError,
                                UnqualifiedPropertiesError)
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/src/caosadvancedtools/example_cfood.py b/src/caosadvancedtools/example_cfood.py
index 2e395d5c..45984998 100644
--- a/src/caosadvancedtools/example_cfood.py
+++ b/src/caosadvancedtools/example_cfood.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -20,7 +20,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 
 from .cfood import AbstractFileCFood, assure_has_property
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/src/caosadvancedtools/export_related.py b/src/caosadvancedtools/export_related.py
index 7ae3a4db..1ac6d2cb 100755
--- a/src/caosadvancedtools/export_related.py
+++ b/src/caosadvancedtools/export_related.py
@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 IndiScale GmbH, Henrik tom Wörden
 #
@@ -24,7 +24,7 @@
 """
 This file allows to create an xml representation of a complete dataset.
 Using the given entity all related entities are collected and saved in a way
-that the data can be imported in another CaosDB instance.
+that the data can be imported in another LinkAhead instance.
 
 Files that are smaller than 1MB are saved in a downloads folder and can be
 imported along with the entities themselves.
@@ -32,9 +32,9 @@ imported along with the entities themselves.
 import argparse
 import os
 
-import caosdb as db
-from caosdb.apiutils import apply_to_ids, retrieve_entities_with_ids
-from caosdb.common.datatype import get_id_of_datatype, is_reference
+import linkahead as db
+from linkahead.apiutils import apply_to_ids, retrieve_entities_with_ids
+from linkahead.common.datatype import get_id_of_datatype, is_reference
 from lxml import etree
 
 
@@ -128,7 +128,7 @@ def export(cont, directory="."):
     xml = etree.tounicode(cont.to_xml(
         local_serialization=True), pretty_print=True)
 
-    with open(os.path.join(directory, "caosdb_data.xml"), "w") as fi:
+    with open(os.path.join(directory, "linkahead_data.xml"), "w") as fi:
         fi.write(xml)
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH, Henrik tom Wörden
diff --git a/src/caosadvancedtools/guard.py b/src/caosadvancedtools/guard.py
index aa37448d..efda79ed 100644
--- a/src/caosadvancedtools/guard.py
+++ b/src/caosadvancedtools/guard.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
 #
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 
 RETRIEVE = 0
 INSERT = 1
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
diff --git a/src/caosadvancedtools/import_from_xml.py b/src/caosadvancedtools/import_from_xml.py
index 9d0e03f6..7bc9f018 100755
--- a/src/caosadvancedtools/import_from_xml.py
+++ b/src/caosadvancedtools/import_from_xml.py
@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 IndiScale GmbH, Henrik tom Wörden
 #
@@ -31,8 +31,8 @@ import argparse
 import os
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
-from caosdb.apiutils import apply_to_ids
+import linkahead as db
+from linkahead.apiutils import apply_to_ids
 from caosadvancedtools.models.data_model import DataModel
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH, Henrik tom Wörden
diff --git a/src/caosadvancedtools/loadFiles.py b/src/caosadvancedtools/loadFiles.py
index cedef367..c9258afa 100755
--- a/src/caosadvancedtools/loadFiles.py
+++ b/src/caosadvancedtools/loadFiles.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -45,7 +45,7 @@ from argparse import ArgumentParser
 from tempfile import NamedTemporaryFile
 from typing import Union
 
-import caosdb as db
+import linkahead as db
 
 logger = logging.getLogger(__name__)
 timeout_fallback = 20
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/src/caosadvancedtools/models/data_model.py b/src/caosadvancedtools/models/data_model.py
index 3be56002..4d4cada2 100644
--- a/src/caosadvancedtools/models/data_model.py
+++ b/src/caosadvancedtools/models/data_model.py
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -34,7 +34,7 @@ import linkahead.common.models as models
 from linkahead.apiutils import compare_entities, describe_diff, merge_entities
 
 
-CAOSDB_INTERNAL_PROPERTIES = [
+LINKAHEAD_INTERNAL_PROPERTIES = [
     "description",
     "name",
     "unit",
@@ -44,19 +44,19 @@ CAOSDB_INTERNAL_PROPERTIES = [
 class DataModel(dict):
     """Provides tools for managing a data model.
 
     When constructing a data model the CaosDB representation can easily be
     created using the classes RecordType and Propery, storing them in a
     Container and inserting it in CaoSDB. However, this has one drawback: You
     cannot simply change someting and update the container. The container will
     insist on having valid ids for all contained Entities.
 
     This class allows you to define your model as easily but also provides you
     with a method (`sync_data_model`) that will sync with the data model in an
-    existing CaosDB instance.
+    existing LinkAhead instance.
 
     This is possible because entities, defined in this model, are identified
-    with entities in CaosDB using names. I.e. a RecordType "Experiment" in this
-    model will update an existing RecordType with name "Experiment" in CaosDB.
+    with entities in LinkAhead using names. I.e. a RecordType "Experiment" in this
+    model will update an existing RecordType with name "Experiment" in LinkAhead.
     Thus, be carefull not to change existing Entities that were created for a
     different purpose (e.g. someone else's experiment).
 
@@ -90,9 +90,9 @@ class DataModel(dict):
             self.append(entity)
 
     def sync_data_model(self, noquestion: bool = False, verbose: bool = True):
         """Synchronize this DataModel with a CaosDB instance.
 
         Updates existing entities from the CaosDB instance and inserts
         non-existing entities into the instance.  Note: This allows to easily
         overwrite changes that were made to an existing data model. Use this
         function with care and double check its effect.
@@ -138,7 +138,7 @@ class DataModel(dict):
             any_change = False
 
             for ent in existing_entities:
-                if ent.name in CAOSDB_INTERNAL_PROPERTIES:
+                if ent.name in LINKAHEAD_INTERNAL_PROPERTIES:
                     # Workaround for the usage of internal properties like name
                     # in via the extern keyword:
                     ref = db.Property(name=ent.name).retrieve()
@@ -171,7 +171,7 @@ class DataModel(dict):
     @staticmethod
     def get_existing_entities(entities):
         """ Return a list with those entities of the supplied iterable that
-        exist in the CaosDB instance.
+        exist in the LinkAhead instance.
 
         Args
         ----
@@ -1,7 +1,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
@@ -44,19 +44,19 @@ CAOSDB_INTERNAL_PROPERTIES = [
     """Provides tools for managing a data model.
 
-    When constructing a data model the CaosDB representation can easily be
+    When constructing a data model the LinkAhead representation can easily be
     created using the classes RecordType and Propery, storing them in a
@@ -44,19 +44,19 @@ CAOSDB_INTERNAL_PROPERTIES = [
     created using the classes RecordType and Propery, storing them in a
-    Container and inserting it in CaoSDB. However, this has one drawback: You
+    Container and inserting it in LinkAhead. However, this has one drawback: You
     cannot simply change someting and update the container. The container will
     insist on having valid ids for all contained Entities.
@@ -90,9 +90,9 @@ class DataModel(dict):
 
     def sync_data_model(self, noquestion: bool = False, verbose: bool = True):
-        """Synchronize this DataModel with a CaosDB instance.
+        """Synchronize this DataModel with a LinkAhead instance.
 
@@ -90,9 +90,9 @@ class DataModel(dict):
 
-        Updates existing entities from the CaosDB instance and inserts
+        Updates existing entities from the LinkAhead instance and inserts
         non-existing entities into the instance.  Note: This allows to easily
         overwrite changes that were made to an existing data model. Use this
diff --git a/src/caosadvancedtools/models/parser.py b/src/caosadvancedtools/models/parser.py
index 175f2f7f..e74de5ac 100644
--- a/src/caosadvancedtools/models/parser.py
+++ b/src/caosadvancedtools/models/parser.py
@@ -1,4 +1,4 @@
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2023 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -49,7 +49,7 @@ import jsonschema
 import linkahead as db
 
 from linkahead.common.datatype import get_list_datatype
-from .data_model import CAOSDB_INTERNAL_PROPERTIES, DataModel
+from .data_model import LINKAHEAD_INTERNAL_PROPERTIES, DataModel
 
 # Keywords which are allowed in data model descriptions.
 KEYWORDS = ["importance",
@@ -200,7 +200,7 @@ def parse_model_from_json_schema(
 
     out : Datamodel
         The datamodel generated from the input schema which then can be used for
-        synchronizing with CaosDB.
+        synchronizing with LinkAhead.
 
     Note
     ----
@@ -301,7 +301,7 @@ debug : bool, optional
 
         # Extern keyword:
         # The extern keyword can be used to include Properties and RecordTypes
         # from existing CaosDB datamodels into the current model.
         # Any name included in the list specified by the extern keyword
         # will be used in queries to retrieve a property or (if no property exists)
         # a record type with the name of the element.
@@ -312,7 +312,7 @@ debug : bool, optional
             ymlmodel["extern"] = []
 
         for name in ymlmodel["extern"]:
-            if name in CAOSDB_INTERNAL_PROPERTIES:
+            if name in LINKAHEAD_INTERNAL_PROPERTIES:
                 self.model[name] = db.Property(name=name).retrieve()
                 continue
             for role in ("Property", "RecordType", "Record", "File"):
@@ -610,7 +610,7 @@ debug : bool, optional
         iterate over properties and check whether it is a base datatype of a
         name that was defined in the model (or extern part)
 
         the string representations are replaced with caosdb objects
 
         """
 
@@ -816,12 +816,12 @@ class JsonSchemaParser(Parser):
             raise JsonSchemaDefinitionError(
                 f"`type` is missing in element {name}.")
         if name == "name":
             # This is identified with the CaosDB name property as long as the
             # type is correct.
             if not elt["type"] == "string" and "string" not in elt["type"]:
                 raise JsonSchemaDefinitionError(
                     "The 'name' property must be string-typed, otherwise it cannot "
-                    "be identified with CaosDB's name property."
+                    "be identified with LinkAhead's name property."
                 )
             return None, force_list
         # LinkAhead suports null for all types, so in the very special case of
@@ -1,4 +1,4 @@
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2023 IndiScale GmbH <info@indiscale.com>
@@ -301,7 +301,7 @@ debug : bool, optional
         # Extern keyword:
         # The extern keyword can be used to include Properties and RecordTypes
-        # from existing CaosDB datamodels into the current model.
+        # from existing LinkAhead datamodels into the current model.
         # Any name included in the list specified by the extern keyword
         # will be used in queries to retrieve a property or (if no property exists)
@@ -610,7 +610,7 @@ debug : bool, optional
         name that was defined in the model (or extern part)
 
-        the string representations are replaced with caosdb objects
+        the string representations are replaced with linkahead objects
 
         """
@@ -816,12 +816,12 @@ class JsonSchemaParser(Parser):
                 f"`type` is missing in element {name}.")
         if name == "name":
-            # This is identified with the CaosDB name property as long as the
+            # This is identified with the LinkAhead name property as long as the
             # type is correct.
             if not elt["type"] == "string" and "string" not in elt["type"]:
diff --git a/src/caosadvancedtools/scifolder/analysis_cfood.py b/src/caosadvancedtools/scifolder/analysis_cfood.py
index adce7225..0216f534 100644
--- a/src/caosadvancedtools/scifolder/analysis_cfood.py
+++ b/src/caosadvancedtools/scifolder/analysis_cfood.py
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractFileCFood,
                                      assure_has_property,
                                      assure_object_is_in_list,
@@ -51,7 +51,7 @@ class AnalysisCFood(AbstractFileCFood, WithREADME):
     @staticmethod
     def name_beautifier(name):
         """ a function that can be used to rename the project. I.e. if
         the project in CaosDB shall be named differently than in the folder
         structure.
         Use discouraged.
         """
@@ -51,7 +51,7 @@ class AnalysisCFood(AbstractFileCFood, WithREADME):
     def name_beautifier(name):
         """ a function that can be used to rename the project. I.e. if
-        the project in CaosDB shall be named differently than in the folder
+        the project in LinkAhead shall be named differently than in the folder
         structure.
         Use discouraged.
diff --git a/src/caosadvancedtools/serverside/examples/example_script.py b/src/caosadvancedtools/serverside/examples/example_script.py
index d97d2d0d..fe9bbaa7 100755
--- a/src/caosadvancedtools/serverside/examples/example_script.py
+++ b/src/caosadvancedtools/serverside/examples/example_script.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -45,7 +45,7 @@ import sys
 from argparse import RawTextHelpFormatter
 from datetime import datetime
 
-import caosdb as db
+import linkahead as db
 import matplotlib.pyplot as plt
 import numpy as np
 from caosadvancedtools.cfood import assure_property_is
@@ -68,18 +68,18 @@ def send_mail(changes: [db.Entity], receipient: str):
 
     Parameters:
     -----------
     changes: The CaosDB entities in the version after the update.
     receipient: The person who shall receive the mail.
     """
 
-    caosdb_config = db.configuration.get_config()
+    linkahead_config = db.configuration.get_config()
     text = """Dear Curator,
 The following changes where done automatically.
 
 {changes}
     """.format(changes="\n".join(changes))
     try:
-        fro = caosdb_config["advancedtools"]["automated_updates.from_mail"]
+        fro = linkahead_config["advancedtools"]["automated_updates.from_mail"]
     except KeyError:
         logger.error("Server Configuration is missing a setting for "
                      "sending mails. The administrator should check "
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
@@ -68,18 +68,18 @@ def send_mail(changes: [db.Entity], receipient: str):
     Parameters:
     -----------
-    changes: The CaosDB entities in the version after the update.
+    changes: The LinkAhead entities in the version after the update.
     receipient: The person who shall receive the mail.
     """
diff --git a/src/caosadvancedtools/serverside/helper.py b/src/caosadvancedtools/serverside/helper.py
index b7289c7f..ec8083ab 100644
--- a/src/caosadvancedtools/serverside/helper.py
+++ b/src/caosadvancedtools/serverside/helper.py
@@ -30,7 +30,7 @@ import sys
 from email import message, policy, utils
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 
 
 def wrap_bootstrap_alert(text, kind):
@@ -165,7 +165,7 @@ def recordtype_is_child_of(rt, parent):
     Parameters
     ----------
 
-    rt : caosdb.Entity
+    rt : linkahead.Entity
         The child RecordType.
     parent : str or int
         The parent's name or id.
@@ -193,7 +193,7 @@ def init_data_model(entities):
     Parameters
     ----------
 
     entities : iterable of caosdb.Entity
         The data model entities which are to be checked for existence.
 
     Raises
@@ -339,7 +339,7 @@ def send_mail(from_addr, to, subject, body, cc=None, bcc=None,
               send_mail_bin=None):
     """ Send an email via the configured send_mail client.
 
     The relevant options in the pycaosdb.ini are:
 
         [Misc]
         sendmail = ...
@@ -365,8 +365,8 @@ def send_mail(from_addr, to, subject, body, cc=None, bcc=None,
     ------
     subprocess.CalledProcessError
         If the sendmail client returned with a non-zero code.
-    caosdb.ConfigurationException
-        If the caosdb configuration has no `Misc.sendmail` configured while the
+    linkahead.ConfigurationException
+        If the linkahead configuration has no `Misc.sendmail` configured while the
         `send_mail_bin` parameter is None.
     """
 
@@ -389,14 +389,14 @@ def send_mail(from_addr, to, subject, body, cc=None, bcc=None,
     if send_mail_bin is not None:
         sendmail = send_mail_bin
     else:
-        caosdb_config = db.configuration.get_config()
+        linkahead_config = db.configuration.get_config()
 
-        if "Misc" not in caosdb_config or "sendmail" not in caosdb_config["Misc"]:
+        if "Misc" not in linkahead_config or "sendmail" not in linkahead_config["Misc"]:
             err_msg = ("No sendmail executable configured. "
                        "Please configure `Misc.sendmail` "
-                       "in your pycaosdb.ini.")
+                       "in your pylinkahead.ini.")
             raise db.ConfigurationError(err_msg)
-        sendmail = caosdb_config["Misc"]["sendmail"]
+        sendmail = linkahead_config["Misc"]["sendmail"]
 
     # construct sendmail command
     # options explained (from `man sendmail`):
@@ -438,7 +438,7 @@ def get_file_via_download(ent, logger=logging.getLogger(__name__)):
     try:
         # TODO remove the following treatment of size=0 when the
         # following issue is resolved:
-        # https://gitlab.com/caosdb/caosdb-server/-/issues/107
+        # https://gitlab.com/linkahead/linkahead-server/-/issues/107
 
         if ent.size > 0:
             val_file = ent.download()
@@ -450,7 +450,7 @@ def get_file_via_download(ent, logger=logging.getLogger(__name__)):
         logger.error("The checksum of the downloaded file with id={} did not "
                      "match.".format(ent.id))
         raise e
-    except db.CaosDBException as e:
+    except db.LinkAheadException as e:
         logger.error("Cannot download the file with id={}.".format(ent.id))
         raise e
 
@@ -193,7 +193,7 @@ def init_data_model(entities):
     ----------
 
-    entities : iterable of caosdb.Entity
+    entities : iterable of linkahead.Entity
         The data model entities which are to be checked for existence.
 
@@ -339,7 +339,7 @@ def send_mail(from_addr, to, subject, body, cc=None, bcc=None,
     """ Send an email via the configured send_mail client.
 
-    The relevant options in the pycaosdb.ini are:
+    The relevant options in the pylinkahead.ini are:
 
         [Misc]
diff --git a/src/caosadvancedtools/structure_mapping.py b/src/caosadvancedtools/structure_mapping.py
index 50e57ac4..bf446c2a 100644
--- a/src/caosadvancedtools/structure_mapping.py
+++ b/src/caosadvancedtools/structure_mapping.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -18,9 +18,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import caosdb as db
-from caosdb.apiutils import resolve_reference
-from caosdb.common.utils import uuid
+import linkahead as db
+from linkahead.apiutils import resolve_reference
+from linkahead.common.utils import uuid
 
 from .cfood import (assure_has_description, assure_has_parent,
                     assure_property_is)
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
diff --git a/src/caosadvancedtools/table_converter.py b/src/caosadvancedtools/table_converter.py
index 7d1097e1..2f0d4cc9 100644
--- a/src/caosadvancedtools/table_converter.py
+++ b/src/caosadvancedtools/table_converter.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
 #
@@ -24,7 +24,7 @@ import argparse
 import re
 import sys
 
-import caosdb as db
+import linkahead as db
 import numpy as np
 import pandas as pd
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
diff --git a/src/caosadvancedtools/table_export.py b/src/caosadvancedtools/table_export.py
index eabb1075..00e644e4 100644
--- a/src/caosadvancedtools/table_export.py
+++ b/src/caosadvancedtools/table_export.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Sprecklelsen <f.spreckelsen@indiscale.com>
@@ -22,7 +22,7 @@
 #
 # ** end header
 #
 """Collect optional and mandatory data from CaosDB records and prepare
 them for an export as a table, e.g., for the export to metadata
 repositories.
 
@@ -31,7 +31,7 @@ from inspect import signature
 import json
 import logging
 
-import caosdb as db
+import linkahead as db
 
 FIND_FUNCTION = "find_func"
 QUERY = "query"
@@ -39,7 +39,7 @@ QUERY = "query"
 logger = logging.getLogger(__name__)
 
 
-class TableExportError(db.CaosDBException):
+class TableExportError(db.LinkAheadException):
     """Error that is raised in case of failing export, e.g., because of
     missing mandatory entries.
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
@@ -22,7 +22,7 @@
 # ** end header
 #
-"""Collect optional and mandatory data from CaosDB records and prepare
+"""Collect optional and mandatory data from LinkAhead records and prepare
 them for an export as a table, e.g., for the export to metadata
 repositories.
diff --git a/src/caosadvancedtools/utils.py b/src/caosadvancedtools/utils.py
index 05000a34..9a0342e9 100644
--- a/src/caosadvancedtools/utils.py
+++ b/src/caosadvancedtools/utils.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -27,8 +27,8 @@ import logging
 import os
 import pathlib
 
-import caosdb as db
-from caosdb.exceptions import TransactionError
+import linkahead as db
+from linkahead.exceptions import TransactionError
 
 logger = logging.getLogger(__name__)
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 IndiScale GmbH <info@indiscale.com>
diff --git a/unittests/caosdbignore-example b/unittests/linkaheadignore-example
similarity index 100%
rename from unittests/caosdbignore-example
rename to unittests/linkaheadignore-example
diff --git a/unittests/test_base_table_exporter.py b/unittests/test_base_table_exporter.py
index 8a65b71a..c69a64a0 100644
--- a/unittests/test_base_table_exporter.py
+++ b/unittests/test_base_table_exporter.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Florian Sprecklelsen <f.spreckelsen@indiscale.com>
@@ -28,7 +28,7 @@ tested without db connection.
 """
 import json
 import os
-import caosdb as db
+import linkahead as db
 from pytest import raises
 from caosadvancedtools import table_export as te
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/unittests/test_cache.py b/unittests/test_cache.py
index de3430bf..1a53f16d 100644
--- a/unittests/test_cache.py
+++ b/unittests/test_cache.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
 #
@@ -26,7 +26,7 @@ from copy import deepcopy
 from tempfile import NamedTemporaryFile
 import sqlite3
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cache import IdentifiableCache, cleanXML
 from lxml import etree
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
diff --git a/unittests/test_cfood.py b/unittests/test_cfood.py
index e2f15ffd..77fd654b 100644
--- a/unittests/test_cfood.py
+++ b/unittests/test_cfood.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -24,7 +24,7 @@
 import re
 import unittest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cfood import (AbstractCFood, AbstractFileCFood, CMeal,
                                      assure_has_parent, assure_has_property,
                                      assure_object_is_in_list,
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/unittests/test_crawler.py b/unittests/test_crawler.py
index 64bf291c..15e783a6 100644
--- a/unittests/test_crawler.py
+++ b/unittests/test_crawler.py
@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2020 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -23,7 +23,7 @@
 import re
 import unittest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.crawler import Crawler
 
 
@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Indiscale GmbH <info@indiscale.com>
diff --git a/unittests/test_generic_analysis.py b/unittests/test_generic_analysis.py
index a1077b97..3e6f4dbc 100644
--- a/unittests/test_generic_analysis.py
+++ b/unittests/test_generic_analysis.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -27,7 +27,7 @@
 module description
 """
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.serverside.generic_analysis import \
     check_referenced_script
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 Indiscale GmbH <info@indiscale.com>
diff --git a/unittests/test_json_schema_model_parser.py b/unittests/test_json_schema_model_parser.py
index a991076e..cdd4c074 100644
--- a/unittests/test_json_schema_model_parser.py
+++ b/unittests/test_json_schema_model_parser.py
@@ -1,5 +1,5 @@
 #
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 # Copyright (C) 2022 Florian Spreckelsen <f.spreckelsen@indiscale.com>
@@ -24,7 +24,7 @@
 import os
 import pytest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.models.parser import (parse_model_from_json_schema,
                                              JsonSchemaDefinitionError)
 
@@ -357,7 +357,7 @@ def test_name_property():
         broken = parse_model_from_json_schema(os.path.join(
             FILEPATH, "datamodel_name_wrong_type.schema.json"))
     assert str(err.value).startswith(
-        "The 'name' property must be string-typed, otherwise it cannot be identified with CaosDB's "
+        "The 'name' property must be string-typed, otherwise it cannot be identified with LinkAhead's "
         "name property.")
 
 
@@ -1,5 +1,5 @@
 #
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
diff --git a/unittests/test_read_md_header.py b/unittests/test_read_md_header.py
index 994f8f16..71873e05 100644
--- a/unittests/test_read_md_header.py
+++ b/unittests/test_read_md_header.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
 #
@@ -25,7 +25,7 @@ import unittest
 from copy import deepcopy
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.read_md_header import get_header
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
diff --git a/unittests/test_result_table_cfood.py b/unittests/test_result_table_cfood.py
index 3341a239..ad0d6397 100644
--- a/unittests/test_result_table_cfood.py
+++ b/unittests/test_result_table_cfood.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
 # Max-Planck-Institute for Dynamics and Self-Organization Göttingen
@@ -32,7 +32,7 @@ import os
 import re
 import unittest
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.scifolder.result_table_cfood import ResultTableCFood
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2018 Research Group Biomedical Physics,
diff --git a/unittests/test_structure_mapping.py b/unittests/test_structure_mapping.py
index 5cc4114f..a426cf78 100644
--- a/unittests/test_structure_mapping.py
+++ b/unittests/test_structure_mapping.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
 # Copyright (C) 2021 Henrik tom Wörden <h.tomwoerden@indiscale.com>
@@ -22,10 +22,10 @@
 import unittest
 from os import name
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.structure_mapping import (EntityMapping,
                                                  collect_existing_structure)
-from caosdb.common import datatype
+from linkahead.common import datatype
 
 
 class structureMappingTest(unittest.TestCase):
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2021 IndiScale GmbH <www.indiscale.com>
diff --git a/unittests/test_table_converter.py b/unittests/test_table_converter.py
index 9b1ac11b..b4f0c4d3 100644
--- a/unittests/test_table_converter.py
+++ b/unittests/test_table_converter.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
 #
@@ -24,9 +24,9 @@ import os
 import unittest
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 import pandas as pd
-from caosdb.apiutils import compare_entities
+from linkahead.apiutils import compare_entities
 from numpy import nan
 
 from caosadvancedtools.table_converter import (from_table, from_tsv, to_table,
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
diff --git a/unittests/test_update_cache.py b/unittests/test_update_cache.py
index 8376da48..318a35ae 100644
--- a/unittests/test_update_cache.py
+++ b/unittests/test_update_cache.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
 #
@@ -26,7 +26,7 @@ import unittest
 from copy import deepcopy
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.cache import UpdateCache, get_pretty_xml
 
 
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2020 Henrik tom Wörden
diff --git a/unittests/test_utils.py b/unittests/test_utils.py
index 468e9200..09688f97 100644
--- a/unittests/test_utils.py
+++ b/unittests/test_utils.py
@@ -2,7 +2,7 @@
 # encoding: utf-8
 #
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
 #
@@ -24,12 +24,12 @@ import logging
 import unittest
 from tempfile import NamedTemporaryFile
 
-import caosdb as db
+import linkahead as db
 from caosadvancedtools.utils import (check_win_path, get_referenced_files,
                                      string_to_person, create_entity_link)
-from caosdb import RecordType, configure_connection, get_config
-from caosdb.connection.mockup import MockUpResponse, MockUpServerConnection
-from caosdb.exceptions import TransactionError
+from linkahead import RecordType, configure_connection, get_config
+from linkahead.connection.mockup import MockUpResponse, MockUpServerConnection
+from linkahead.exceptions import TransactionError
 
 
 class BaseMockUpTest(unittest.TestCase):
@@ -2,7 +2,7 @@
 #
 # ** header v3.0
-# This file is a part of the CaosDB Project.
+# This file is a part of the LinkAhead project.
 #
 # Copyright (C) 2019 Henrik tom Wörden
-- 
GitLab